Enum hexagonal_pathfinding_astar::HexOrientation [−][src]
pub enum HexOrientation {
FlatTopOddUp,
FlatTopOddDown,
}Expand description
Specifies the orientation of the hexagon space in Offset layouts. This is important for determining the available neighbouring nodes during expansion.
Flat-top odd columns moved up
___
___/ O \
/ E \___/
\___/Flat-top odd columns moved down
___
/ E \___
\___/ O \
\___/